@@ -1,7 +1,7 @@
 package Net::BitTorrent::Protocol;
 use strict;
 use warnings;
-our $MAJOR = 1; our $MINOR = 0; our $PATCH = 2; our $DEV = ''; our $VERSION = sprintf('%0d.%0d.%0d' . ($DEV =~ m[\S] ? '-%s' : ''), $MAJOR, $MINOR, $PATCH, $DEV);
+our $VERSION = "1.5.0";
 use lib '../../../lib';
 use Net::BitTorrent::Protocol::BEP03 qw[:all];
 use Net::BitTorrent::Protocol::BEP03::Bencode qw[:all];
@@ -11,6 +11,7 @@ use Net::BitTorrent::Protocol::BEP07 qw[:all];
 use Net::BitTorrent::Protocol::BEP09 qw[:all];
 use Net::BitTorrent::Protocol::BEP10 qw[:all];
 use Net::BitTorrent::Protocol::BEP23 qw[:all];
+use Net::BitTorrent::Protocol::BEP44 qw[:all];
 use Carp qw[carp];
 use vars qw[@EXPORT_OK %EXPORT_TAGS];
 use Exporter qw[];
@@ -20,15 +21,18 @@ use Exporter qw[];
               @{$Net::BitTorrent::Protocol::BEP05::EXPORT_TAGS{build}},
               @{$Net::BitTorrent::Protocol::BEP06::EXPORT_TAGS{build}},
               @{$Net::BitTorrent::Protocol::BEP09::EXPORT_TAGS{build}},
-              @{$Net::BitTorrent::Protocol::BEP10::EXPORT_TAGS{build}}
+              @{$Net::BitTorrent::Protocol::BEP10::EXPORT_TAGS{build}},
+              @{$Net::BitTorrent::Protocol::BEP44::EXPORT_TAGS{build}}
     ],
     bencode => [@{  $Net::BitTorrent::Protocol::BEP03::Bencode::EXPORT_TAGS{all}
-                    },
+                },
     ],
     compact => [@{$Net::BitTorrent::Protocol::BEP07::EXPORT_TAGS{all}},
                 @{$Net::BitTorrent::Protocol::BEP23::EXPORT_TAGS{all}}
     ],
-    dht   => [@{$Net::BitTorrent::Protocol::BEP05::EXPORT_TAGS{all}}],
+    dht => [@{$Net::BitTorrent::Protocol::BEP05::EXPORT_TAGS{all}},
+            @{$Net::BitTorrent::Protocol::BEP44::EXPORT_TAGS{build}}
+    ],
     parse => [@{$Net::BitTorrent::Protocol::BEP03::EXPORT_TAGS{parse}},
               @{$Net::BitTorrent::Protocol::BEP06::EXPORT_TAGS{parse}},
               @{$Net::BitTorrent::Protocol::BEP10::EXPORT_TAGS{parse}},
@@ -43,7 +47,6 @@ use Exporter qw[];
 @EXPORT_OK = sort map { @$_ = sort @$_; @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{'all'} = \@EXPORT_OK;
 my $parse_packet_dispatch;
-
 #
 sub parse_packet ($) {
     $parse_packet_dispatch ||= {$KEEPALIVE      => \&parse_keepalive,
@@ -111,6 +114,15 @@ Packet = %s
 END
             }
         }
+        else {
+            $packet = {packet_length => $packet_length,
+                       fatal         => 0,
+                       error         => 'Not enough data yet! We need '
+                           . $packet_length
+                           . ' bytes but have '
+                           . length $$data
+            };
+        }
     }
     return $packet;
 }
@@ -133,8 +145,8 @@ In addition to the functions found in L<Net::BitTorrent::Protocol::BEP03>,
 L<Net::BitTorrent::Protocol::BEP03::Bencode>,
 L<Net::BitTorrent::Protocol::BEP06>, L<Net::BitTorrent::Protocol::BEP07>,
 L<Net::BitTorrent::Protocol::BEP09>, L<Net::BitTorrent::Protocol::BEP10>,
-L<Net::BitTorrent::Protocol::BEP23>, TODO..., a function which wraps all the
-packet parsing functions is provided:
+L<Net::BitTorrent::Protocol::BEP23>, L<Net::BitTorrent::Protocol::BEP44>,
+TODO..., a function which wraps all the packet parsing functions is provided:
 
 =over
 
@@ -187,7 +199,8 @@ Imports the compact and inflation functions for IPv4
 
 =item C<dht>
 
-Imports all functions related to L<BEP05|Net::BitTorrent::Protocol::BEP05>.
+Imports all functions related to L<BEP05|Net::BitTorrent::Protocol::BEP05> and
+L<BEP44|Net::BitTorrent::Protocol::BEP44>.
 
 =item C<parse>
 
@@ -223,6 +236,8 @@ http://bittorrent.org/beps/bep_0009.html - Extension for Peers to Send Metadata
 
 http://bittorrent.org/beps/bep_0010.html - Extension Protocol
 
+http://bittorrent.org/beps/bep_0044.html - Storing arbitrary data in the DHT
+
 http://wiki.theory.org/BitTorrentSpecification - An annotated guide to
 the BitTorrent protocol
 
